@@ -7,7 +7,7 @@
 ;;;; Author:   Kevin M. Rosenberg
 ;;;; Created:  Feb 2002
 ;;;;
-;;;; $Id: mysql-loader.lisp 10612 2005-07-06 00:50:20Z kevin $
+;;;; $Id: mysql-loader.lisp 11102 2006-09-06 12:51:12Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002-2004 by Kevin M. Rosenberg
 ;;;;
@@ -18,13 +18,10 @@
 
 (in-package #:mysql)
 
-(defparameter *clsql-mysql-library-candidate-names* 
-  (list #+(or 64bit x86-64) "clsql_mysql64"
-        #+(or 64bit x86-64) (make-pathname :name "clsql_mysql64"
-                                           :directory (pathname-directory *load-truename*))
-        "clsql_mysql"
-        (make-pathname :name "clsql_mysql"
-                       :directory (pathname-directory *load-truename*))))
+;; searches clsql_mysql64 to accomodate both 32-bit and 64-bit libraries on same system
+(defparameter *clsql-mysql-library-candidate-names*
+  `(,@(when (> most-positive-fixnum (expt 2 32)) (list "clsql_mysql64"))
+    "clsql_mysql"))
 
 (defvar *mysql-library-candidate-names*
   '("libmysqlclient" "libmysql"))
@@ -39,13 +36,15 @@ set to the right path before compiling or loading the system.")
 
 (defmethod clsql-sys:database-type-library-loaded ((database-type (eql :mysql)))
   *mysql-library-loaded*)
-				      
+
 (defmethod clsql-sys:database-type-load-foreign ((database-type (eql :mysql)))
+  (clsql:push-library-path
+   (make-pathname :directory clsql-mysql-system::*library-file-dir*))
   (clsql-uffi:find-and-load-foreign-library *mysql-library-candidate-names*
-                                            :module "mysql" 
+                                            :module "mysql"
                                             :supporting-libraries *mysql-supporting-libraries*)
   (clsql-uffi:find-and-load-foreign-library *clsql-mysql-library-candidate-names*
-                                            :module "clsql-mysql" 
+                                            :module "clsql-mysql"
                                             :supporting-libraries *mysql-supporting-libraries*)
   (setq *mysql-library-loaded* t))
 
