@@ -6,7 +6,7 @@
 ;;;; Purpose:  Low-level ODBC API using UFFI
 ;;;; Authors:  Kevin M. Rosenberg and Paul Meurer
 ;;;;
-;;;; $Id: odbc-api.lisp 10893 2006-02-28 16:07:58Z kevin $
+;;;; $Id: odbc-api.lisp 11014 2006-08-12 19:43:22Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2004 by Kevin M. Rosenberg
 ;;;; and Copyright (C) Paul Meurer 1999 - 2001. All rights reserved.
@@ -99,6 +99,17 @@ as possible second argument) to the desired representation of date/time/timestam
                                    odbc-call &body body)
   (let ((result-code (gensym "RC-")))
     `(let ((,result-code ,odbc-call))
+
+      ;; Check for allegro v7 & v8 bug with ODBC calls returning
+      ;; 32-bit unsigned ints, not 16-bit signed ints
+      #+(and allegro mswindows)
+      (when (> ,result-code #xFFFF)
+        (warn (format nil "16-bit return bug: result-code #x~X for expression ~S"
+                      ,result-code (quote ,odbc-call)))
+        (setq ,result-code (logand ,result-code #xFFFF))
+        (when (> ,result-code #x7FFF)
+          (setq ,result-code (- ,result-code #x10000))))
+
        (case ,result-code
          (#.$SQL_SUCCESS
           (progn ,result-code ,@body))
@@ -132,8 +143,7 @@ as possible second argument) to the desired representation of date/time/timestam
 	     :secondary-error-id sql-state)))
 	 (#.$SQL_NO_DATA_FOUND
 	  (progn ,result-code ,@body))
-	 ;; work-around for Allegro 7.0beta AMD64 which
-	 ;; has for negative numbers
+	 ;; work-around for Allegro 7.0beta AMD64 which returns negative numbers
 	 (otherwise
 	  (multiple-value-bind (error-message sql-state)
 	      (handle-error (or ,henv +null-handle-ptr+)
