@@ -7,7 +7,7 @@
 ;;;; Programmers:   Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: postgresql-socket-package.lisp 10155 2004-11-12 03:31:00Z kevin $
+;;;; $Id: postgresql-socket-package.lisp 10904 2006-03-21 02:51:09Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -21,7 +21,7 @@
 #+lispworks (require "comm")
 
 (defpackage #:postgresql-socket
-  (:use #:cl #-sbcl md5 #+sbcl sb-md5)
+  (:use #:cl md5)
   (:export #:pgsql-ftype
 	   #:pgsql-ftype#bytea
 	   #:pgsql-ftype#int2
