@@ -7,7 +7,7 @@
 ;;;; Authors:  Aurelio Bignoli
 ;;;; Created:  Oct 2004
 ;;;;
-;;;; $Id: sqlite3-sql.lisp 10275 2005-01-23 05:28:03Z kevin $
+;;;; $Id: sqlite3-sql.lisp 11326 2006-12-01 03:09:33Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2004 by Aurelio Bignoli
 ;;;;
@@ -181,8 +181,8 @@
 		(setf (sqlite3-result-set-n-col result-set) 0))
 	    (sqlite3:sqlite3-error (err)
 	      (error 'sql-database-error
-		     :message "Error in sqlite3-step: ~A"
-		     (sqlite3:sqlite3-error-message err))))
+		     :message (format nil "Error in sqlite3-step: ~A"
+                                      (sqlite3:sqlite3-error-message err)))))
 	  t))))
 
 
