@@ -1,7 +1,7 @@
 ;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
 ;;;; *************************************************************************
 ;;;;
-;;;; $Id: generic-postgresql.lisp 10969 2006-07-05 02:16:49Z kevin $
+;;;; $Id: generic-postgresql.lisp 11026 2006-08-14 06:54:32Z kevin $
 ;;;;
 ;;;; Generic postgresql layer, used by db-postgresql and db-postgresql-socket
 ;;;;
@@ -15,7 +15,7 @@
 (in-package #:clsql-sys)
 
 (defclass generic-postgresql-database (database)
-  ()
+  ((has-table-pg_roles :type boolean :reader has-table-pg_roles :initform nil))
   (:documentation "Encapsulate same behavior across postgresql and postgresql-socket backends."))
 
 
@@ -70,15 +70,32 @@
      " AND (relowner=(SELECT usesysid FROM pg_user WHERE (usename='~A')))"
      owner))
    ((null owner)
-    (format nil " AND (NOT (relowner=1))"))
+    (format nil " AND (relowner<>(SELECT usesysid FROM pg_user WHERE usename='postgres'))"))
    (t "")))
 
+(defun has-table (name database)
+  (let ((name-retrieved
+         (caar (database-query
+                (format nil "SELECT relname FROM pg_class WHERE relname='~A'"
+                        name)
+                database nil nil))))
+    (if (and (stringp name-retrieved) (plusp (length name-retrieved)))
+        t
+        nil)))
+
+(defmethod slot-unbound (class (obj generic-postgresql-database)
+                         (slot (eql 'has-table-pg_roles)))
+  ;; Lazily cache slot value
+  (declare (ignore class))
+  (setf (slot-value obj 'has-table-pg_roles) (has-table "pg_roles" obj)))
+
 (defun database-list-objects-of-type (database type owner)
   (mapcar #'car
 	  (database-query
 	   (format nil
-                   (if (not (eq owner :all))
-                    "
+                   (if (and (has-table-pg_roles database)
+                            (not (eq owner :all)))
+                       "
  SELECT c.relname
  FROM pg_catalog.pg_class c
       LEFT JOIN pg_catalog.pg_roles r ON r.oid = c.relowner
@@ -87,7 +104,7 @@
        AND n.nspname NOT IN ('pg_catalog', 'pg_toast')
        AND pg_catalog.pg_table_is_visible(c.oid)
        ~A"
-                    "SELECT relname FROM pg_class WHERE (relkind =
+                       "SELECT relname FROM pg_class WHERE (relkind =
 '~A')~A")
 		   type
 		   (owner-clause owner))
