@@ -7,7 +7,7 @@
 ;;;; Programmer:   Kevin M. Rosenberg
 ;;;; Date Started: Mar 2002
 ;;;;
-;;;; $Id: utils.lisp 10284 2005-01-27 05:56:00Z kevin $
+;;;; $Id: utils.lisp 10820 2005-11-11 16:26:08Z kevin $
 ;;;;
 ;;;; This file, part of CLSQL, is Copyright (c) 2002-2004 by Kevin M. Rosenberg
 ;;;;
@@ -21,7 +21,7 @@
 (defun number-to-sql-string (num)
   (etypecase num
     (integer
-     num)
+     (princ-to-string num))
     (rational
      (float-to-sql-string (coerce num 'double-float)))
     (number
